summaryrefslogtreecommitdiff
path: root/TAO/tao/LF_Event_Binder.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/LF_Event_Binder.h')
-rw-r--r--TAO/tao/LF_Event_Binder.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/TAO/tao/LF_Event_Binder.h b/TAO/tao/LF_Event_Binder.h
index cb011d13614..1cc7a32afa5 100644
--- a/TAO/tao/LF_Event_Binder.h
+++ b/TAO/tao/LF_Event_Binder.h
@@ -20,20 +20,20 @@
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-class TAO_Follower;
+class TAO_LF_Follower;
/**
- * @brief Implement an auto_ptr-like class for the TAO_Followers
+ * @brief Implement an auto_ptr-like class for the TAO_LF_Followers
* allocated via a TAO_Leader_Follower set.
*
* The Leader/Follower set is a factory for TAO_Follower objects
*/
class TAO_Export TAO_LF_Event_Binder
{
public:
/// Constructor
TAO_LF_Event_Binder (TAO_LF_Event *event,
- TAO_Follower *folloer);
+ TAO_LF_Follower *folloer);
/// Destructor
~TAO_LF_Event_Binder (void);
@@ -20,20 +20,20 @@
* allocated via a TAO_Leader_Follower set.
*
- * The Leader/Follower set is a factory for TAO_Follower objects
+ * The Leader/Follower set is a factory for TAO_LF_Follower objects
*/
class TAO_Export TAO_LF_Event_Binder